LiftofSettings

Struct LiftofSettings 

pub struct LiftofSettings {
Show 23 fields pub config_version: Option<String>, pub staging_dir: String, pub calibration_dir: String, pub db_path: String, pub runtime_sec: u64, pub mtb_address: String, pub cpu_moni_interval_sec: u64, pub rb_ignorelist_always: Vec<u8>, pub rb_ignorelist_run: Vec<u8>, pub run_analysis_engine: bool, pub rb_controls_pb_and_ltb: Option<Vec<u8>>, pub pre_run_calibration: bool, pub save_cali_wf: bool, pub verification_run: Option<bool>, pub mtb_settings: MTBSettings, pub event_builder_settings: TofEventBuilderSettings, pub analysis_engine_settings: AnalysisEngineSettings, pub data_publisher_settings: DataPublisherSettings, pub cmd_dispatcher_settings: CommandDispatcherSettings, pub rb_settings: RBSettings, pub rb_channel_mask: ChannelMaskSettings, pub preamp_settings: PreampSettings, pub ltb_settings: LTBThresholdSettings,
}

Fields

config_version: Option<String>

The config version indicates, which version of Liftof of this file is intended for, e.g. “0.11”

staging_dir: String

read run .toml files from this directory and automotically work through them 1by1

calibration_dir: String

default location for RBCalibration files

db_path: String

default location for the database

runtime_sec: u64

Runtime in seconds

mtb_address: String

The UDP port to be used to get packets from the MTB

cpu_moni_interval_sec: u64

The interval (in seconds) to retrive CPUMoniData from the TOF CPU

rb_ignorelist_always: Vec<u8>

In an intervall from 1-50, these RB simply do not exist or might have never existed. Always ingore these

rb_ignorelist_run: Vec<u8>

ignore these specific RB for this run

run_analysis_engine: bool

Should TofHits be generated?

rb_controls_pb_and_ltb: Option<Vec<u8>>

RB contols both, LTB and PB

pre_run_calibration: bool

Run a full RB calibration before run start?

save_cali_wf: bool

Should the waveforms which go into te calibration be saved in the package?

verification_run: Option<bool>

Do a verification run before each run? The purpose of the verification run is to generate a “DetectorStatus” packet. If a verification run is desired, change this number to the number of seconds to do the verification run If this is set, don’t save anything to disk and just transmit the TofDetectorStatus packet

mtb_settings: MTBSettings

Settings to control the MTB

event_builder_settings: TofEventBuilderSettings

Settings for the TOF event builder

analysis_engine_settings: AnalysisEngineSettings

Settings for the analysis engine

data_publisher_settings: DataPublisherSettings

Configure data publshing and saving on local disc

cmd_dispatcher_settings: CommandDispatcherSettings

Configure cmmand reception and sending

rb_settings: RBSettings

Settings for the individual RBs

rb_channel_mask: ChannelMaskSettings

Mask individual channels (e.g. dead preamps) for the readout boards

preamp_settings: PreampSettings

Preamp configuration

ltb_settings: LTBThresholdSettings

LTB threshold configuration

Implementations

Source

impl LiftofSettings

pub fn new() -> Self

pub fn from_tofrunconfig(&mut self, cfg: &TofRunConfig)

Change the settings according to the ones in the given config

pub fn to_toml(&self, filename: String)

Write the settings to a toml file

pub fn to_json(&self, filename: String)

Write the settings to a json file

pub fn from_toml(filename: &str) -> Result<LiftofSettings, SerializationError>