pub struct TofEventBuilderSettings {Show 31 fields
pub cachesize: u32,
pub n_mte_per_loop: u32,
pub n_rbe_per_loop: u32,
pub te_timeout_sec: u32,
pub te_timeout_sec_combo: Option<u32>,
pub holdoff: Option<u32>,
pub sort_events: bool,
pub build_strategy: BuildStrategy,
pub greediness: u8,
pub wait_nrb: u8,
pub hb_send_interval: u16,
pub no_expect_dead_rbs: Option<bool>,
pub ignore_mtb_link_ids: Option<Vec<u8>>,
pub only_save_interesting: bool,
pub thr_n_hits_umb: Option<u8>,
pub thr_n_hits_cbe: Option<u8>,
pub thr_n_hits_cor: Option<u8>,
pub thr_n_hits_outer: Option<u8>,
pub thr_tot_edep_outer: Option<f32>,
pub thr_tot_edep_umb: Option<f32>,
pub thr_tot_edep_cbe: Option<f32>,
pub thr_tot_edep_cor: Option<f32>,
pub rbe_purge_limit1: Option<u32>,
pub rbe_purge_limit1_n: Option<u32>,
pub rbe_purge_ev_time1: Option<u32>,
pub rbe_purge_limit2: Option<u32>,
pub rbe_purge_limit2_n: Option<i32>,
pub rbe_purge_ev_time2: Option<u32>,
pub rbe_purge_limit3: Option<u32>,
pub rbe_purge_limit3_n: Option<i32>,
pub rbe_purge_ev_time3: Option<u32>,
}Expand description
Settings to change the configuration of the TOF Eventbuilder
Fields
cachesize: u32n_mte_per_loop: u32n_rbe_per_loop: u32te_timeout_sec: u32The timeout parameter for the TofEvent. If not complete after this time, send it onwards anyway
te_timeout_sec_combo: Option<u32>The timeout parameter for the TofEvent, but only for the combo trigger part.
holdoff: Option<u32>Only do something when holdoff time has passed
sort_events: booltry to sort the events by id (uses more resources)
build_strategy: BuildStrategygreediness: u8wait_nrb: u8hb_send_interval: u16no_expect_dead_rbs: Option<bool>Analyze the trigger hits and check if the hits are expected from a known dead RB. if so, then adjust the expectation of number of readoutboards by subtracting the number of expected dead boards from the seen rb_link_ids in this event
ignore_mtb_link_ids: Option<Vec<u8>>only_save_interesting: boolAllows to restrict saving the event to disk based on the interesting event parameters (These are minimum values)
thr_n_hits_umb: Option<u8>thr_n_hits_cbe: Option<u8>thr_n_hits_cor: Option<u8>thr_n_hits_outer: Option<u8>thr_tot_edep_outer: Option<f32>thr_tot_edep_umb: Option<f32>thr_tot_edep_cbe: Option<f32>thr_tot_edep_cor: Option<f32>rbe_purge_limit1: Option<u32>rbe_purge_limit1_n: Option<u32>rbe_purge_ev_time1: Option<u32>rbe_purge_limit2: Option<u32>rbe_purge_limit2_n: Option<i32>rbe_purge_ev_time2: Option<u32>rbe_purge_limit3: Option<u32>rbe_purge_limit3_n: Option<i32>rbe_purge_ev_time3: Option<u32>Implementations
Sourceimpl TofEventBuilderSettings
impl TofEventBuilderSettings
pub fn new() -> TofEventBuilderSettings